#include <iostream>
#include <ctype.h>
#include <math.h>

using namespace std;

const int MAXGRID = 100;

char (*grid)[MAXGRID];
const char H_BOUND = '-';
const char V_BOUND = '|';
const char CORNER = '*';
const int ROW = 0;  // indices in arrays corner, dim, minDim
const int COL = 1;

#define max(a, b) ( (a) < (b) ? b : a )

class Split 
{
public:
    char ch;                // letter label, '-' or '|'
    Split *child1, *child2;   // child1 is top or left,  child2 is bottom or right
    int *corner, *dim, *minDim; // index 0 for row, index 1 for column
    // top left corner, dimensions, and minimum dimensions of the window
    // each is not mutated after it is set, so references may be reused
    int iSplit, // index 0 or 1 for arrays corner, dim, and minDim direction
        iSame;  // iSplit is the index of the split coordinate, iSame of the other
    // these variables allow much code to be common for subwindows,
    // no matter what the direction of the split

    Split()
    {   // recursive constructor, creates subwindows
        //  does not set corner and dim arrays
        child1 = child2 = NULL;
        corner = dim = minDim = NULL;

        cin >> ch;

        if ( isalpha(ch) ) {
            minDim = new int[2];
            minDim[0] = minDim[1] = 2;
        }
        else {
            child1 = new Split;
            child2 = new Split;
            if ( ch == H_BOUND )
                iSplit = ROW;
            else
                iSplit = COL;
            iSame = 1 - iSplit;
            minDim = new int[2];
            minDim[iSplit] = child1->minDim[iSplit] + child2->minDim[iSplit];
            minDim[iSame] = max(child1->minDim[iSame], child2->minDim[iSame]);
        }
    }

    void setWalls(int nextCorner[], int nextDim[]) 
    {
        // set corner and dim arrays recursively and set walls in undivided windows
        corner = nextCorner;
        dim = nextDim;
        if (child1 == NULL) {
            for (int r = corner[0]+1; r < corner[0] + dim[0]; r++){
                grid[r][corner[1]] = V_BOUND;
                grid[r][corner[1]+dim[1]] = V_BOUND;
            }
            for (int c = corner[1]+1; c < corner[1] + dim[1]; c++){
                grid[corner[0]][c] = H_BOUND;
                grid[corner[0]+dim[0]][c] = H_BOUND;
            }
        }
        else {
            int splitDim1 = (int)ceil(child1->minDim[iSplit]*((double)dim[iSplit])/minDim[iSplit] );
            nextDim = new int[2];
            nextDim[0] = dim[0];
            nextDim[1] = dim[1];
            nextDim[iSplit] = splitDim1;
            child1->setWalls(corner, nextDim);
            nextDim = new int[2];
            nextDim[0] = dim[0];
            nextDim[1] = dim[1];
            nextDim[iSplit] -= splitDim1;
            nextCorner = new int[2];
            nextCorner[0] = corner[0];
            nextCorner[1] = corner[1];
            nextCorner[iSplit] += splitDim1;
            child2->setWalls(nextCorner, nextDim);
        }
    }

    void setCorners() {
        // recursively sets label and asterisks for undivided windows
        // Asterisks may be overwritten by other labels later, but because of the
        //   recursive order, top left corners are not overwritten later.
        if (child1 == NULL) {
            grid[corner[0]][corner[1]] = ch;
            grid[corner[0]+dim[0]][corner[1]] = CORNER;
            grid[corner[0]][corner[1]+dim[1]] = CORNER;
            grid[corner[0]+dim[0]][corner[1]+dim[1]] = CORNER;
        }
        else {
            child1->setCorners();
            child2->setCorners();
        }
    }
};

int main() 
{
    int r, c, total;
    
    cin >> total;
    
    for (int i = 1; i <= total; i++) {
        cout << i << endl;
        Split *mainWindow = new Split;
        int* mainDim = mainWindow->minDim;
        grid = new char[mainDim[0]+1][MAXGRID];

        for (r = 1; r < mainDim[0]; r++) // fill inside main window
            for (c = 1; c < mainDim[1]; c++)
                grid[r][c] = ' ';
        
        int *initcorners = new int[2];
        initcorners[0] = initcorners[1] = 0;

        mainWindow->setWalls(initcorners, mainDim);
        mainWindow->setCorners(); // overwrites some walls
        for (r = 0; r <= mainDim[0]; r++) {
            for (c = 0; c <= mainDim[1]; c++)
                cout << grid[r][c];
            cout << endl;
        }
    }
}
